pub struct DuckDbConnectionManager { /* private fields */ }Expand description
An r2d2::ManageConnection that creates connections from a shared Database.
Implementations
Sourceimpl DuckDbConnectionManager
impl DuckDbConnectionManager
Sourcepub fn new(database: Database) -> DuckDbConnectionManager
pub fn new(database: Database) -> DuckDbConnectionManager
Creates a manager over an already-open Database.
Sourcepub fn file<P: AsRef<Path>>(path: P) -> Result<DuckDbConnectionManager>
pub fn file<P: AsRef<Path>>(path: P) -> Result<DuckDbConnectionManager>
Creates a manager backed by a file-based database.
Errors
Returns an error if the database cannot be opened.
Sourcepub fn file_with_flags<P: AsRef<Path>>(
path: P,
config: Config,
) -> Result<DuckDbConnectionManager>
pub fn file_with_flags<P: AsRef<Path>>( path: P, config: Config, ) -> Result<DuckDbConnectionManager>
Creates a manager backed by a file-based database with additional config.
Errors
Returns an error if the database cannot be opened.
Sourcepub fn memory() -> Result<DuckDbConnectionManager>
pub fn memory() -> Result<DuckDbConnectionManager>
Creates a manager backed by a shared in-memory database.
All connections checked out of a pool built from this manager observe the same in-memory data.
Errors
Returns an error if the database cannot be opened.
Sourcepub fn memory_with_flags(config: Config) -> Result<DuckDbConnectionManager>
pub fn memory_with_flags(config: Config) -> Result<DuckDbConnectionManager>
Creates a manager backed by a shared in-memory database with additional config.
Errors
Returns an error if the database cannot be opened.